.. currentmodule:: iniabu.isotopes

===============
Isotope Queries
===============


:class:`Isotopes` Querying Class
--------------------------------

.. autoclass:: Isotopes
    :members:
    :undoc-members:
